@@ -10,7 +10,19 @@ Can also import settings from a previously saved metadata file.
 
 Created on 29 Mar 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: GPL3
+
+This file is part of PyMandel.
+
+PyMandel is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
+
+PyMandel is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with PyMandel. If not, see <https://www.gnu.org/licenses/>. 
 """
 
 from json import loads
@@ -129,7 +141,6 @@ class BatchMandelbrot:
         self.mandelbrot.cancel_plot()  # Cancel any in-flight plot
 
         for i in range(self._frames):
-
             self._currframe = i
             fqname = self._filepath + "/" + self._filename + "_" + str(i + 1).zfill(3)
             print("Creating file " + fqname + " ...")
