@@ -5,7 +5,19 @@ This handles all the settings and file storage/retrieval.
 
 Created on 3 Apr 2020
 
-@author: semuadmin
+:author: semuadmin
+:copyright: SEMU Consulting © 2020
+:license: GPL3
+
+This file is part of PyMandel.
+
+PyMandel is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
+
+PyMandel is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with PyMandel. If not, see <https://www.gnu.org/licenses/>. 
 """
 
 from tkinter import (
@@ -818,7 +830,6 @@ class SettingsFrame(Frame):
 
         # Parse file
         try:
-
             settings = loads(jsondata).get(MODULENAME)
 
             # Set plot parameters
